-- Fichero DBVisualFSQLins.sql
-------------------------------------------------------------------
-- INSTALACIN de una Base de Datos Difusa (FDB, Fuzzy Database) --
-- CREACIN de las TABLAS insercin de algunas tuplas en ellas,  --
-- as como creacin de elementos en la FMB de esta Bd           --
-- (etiquetas...).                                               --
-- Para la instalacin no hace falta desinstalarla previamente.  --
-- Debe ejecutarse por el usuario que ser propietario de las    --
-- tablas de la Bd (no necesariamente un DBA).                   --
-------------------------------------------------------------------
-- Para que salgan los mensajes (de put_line) al instalar desde FSQL*Plus:
set serveroutput on
-- Para que salgan (o no) las ordenes a ejecutar: set echo on
set echo off
-- Para que no salgan los mensajes cuando todo va bien (los errores si salen):
set feedback off

exec dbms_output.put_line('>>>>');
exec dbms_output.put_line('>>>> ****************************************** <<<<');
exec dbms_output.put_line('>>>> **** INSTALACIN de una Base de Datos **** <<<<');
exec dbms_output.put_line('>>>> **** Difusa de ejemplo.               **** <<<<');
exec dbms_output.put_line('>>>> ****************************************** <<<<');
exec dbms_output.put_line('>>>>');
exec dbms_output.put_line('>>>> NOTAS:');
exec dbms_output.put_line('>>>>   - Es requisito indispensable que est instalado FIRST (tablas de la FMB...).');
exec dbms_output.put_line('>>>>   - No importa si se producen errores al intentar borrar');
exec dbms_output.put_line('>>>>     TABLAS que no existan (ORA-00942).');
exec dbms_output.put_line('>>>>   - Cualquier otro error podr impedir la correcta consulta a esta Bd.');
exec dbms_output.put_line('>>>>     En ese caso revise el cdigo del error y el lugar donde ha ocurrido.');
exec dbms_output.put_line('>>>>');


-- TABLA EMPLEADOS

exec dbms_output.put_line('>>>> Borrando y Creando tabla EMPLEADOS...');
DROP   TABLE EMPLEADOS CASCADE CONSTRAINTS;
CREATE TABLE EMPLEADOS(
  EMP# NUMBER(4) NOT NULL,
  NOMBRE CHAR(20) NOT NULL,
  APELLIDOS CHAR(40) NOT NULL,
  SEXO CHAR(1) NOT NULL,
  EDADT NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (EDADT BETWEEN 0 AND 7)
      CONSTRAINT NULL_INVALIDO_EDAD      CHECK (EDADT<>2)
      CONSTRAINT UNDEFINED_INVALIDO_EDAD CHECK (EDADT<>1),
  EDAD1 NUMBER(3),
  EDAD2 NUMBER(3),
  EDAD3 NUMBER(3),
  EDAD4 NUMBER(3),
  TELEFONO CHAR(12) NOT NULL,
  PRIMARY KEY (EMP#));


-- TABLA APTITUDES

exec dbms_output.put_line('>>>> Borrando y Creando tabla APTITUDES...');
DROP   TABLE APTITUDES CASCADE CONSTRAINTS;
CREATE TABLE APTITUDES(
  EMP# NUMBER(4) NOT NULL,
  ESTUDIOST NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (ESTUDIOST BETWEEN 0 AND 7), -- LIMITAMOS A 8(0-7), LOS TIPOS DE TRIBUTOS TIPO2
  ESTUDIOS1 NUMBER(2),
  ESTUDIOS2 NUMBER(2),
  ESTUDIOS3 NUMBER(2),
  ESTUDIOS4 NUMBER(2),
  PROFESIONT NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (PROFESIONT BETWEEN 0 AND 4),       -- LIMITAMOS A 5(0-4), LOS TIPOS DE TRIBUTOS TIPO3
  PROFESIONP1 NUMBER(3,2),
  PROFESION1 NUMBER(3) NOT NULL, -- FUZZY_OBJECT_LIST.FUZZY_ID%TYPE
  EXPERIENCIAT NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (EXPERIENCIAT BETWEEN 0 AND 7), -- LIMITAMOS A 8(0-7), LOS TIPOS DE TRIBUTOS TIPO2
  EXPERIENCIA1 NUMBER(2),
  EXPERIENCIA2 NUMBER(2),
  EXPERIENCIA3 NUMBER(2),
  EXPERIENCIA4 NUMBER(2),
  PRIMARY KEY (EMP#),
  FOREIGN KEY (EMP#) REFERENCES EMPLEADOS ON DELETE CASCADE);


-- TABLA DEPARTAMENTOS

exec dbms_output.put_line('>>>> Borrando y Creando tabla DEPARTAMENTOS...');
DROP   TABLE DEPARTAMENTOS CASCADE CONSTRAINTS;
CREATE TABLE DEPARTAMENTOS(
  DPTO#   NUMBER(4)  NOT NULL,
  NOMBRE  CHAR(20) NOT NULL,
  BENEFICIOST NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (BENEFICIOST BETWEEN 0 AND 7), -- LIMITAMOS A 8(0-7), LOS TIPOS DE TRIBUTOS TIPO2
  BENEFICIOS1 NUMBER(8),
  BENEFICIOS2 NUMBER(8),
  BENEFICIOS3 NUMBER(8),
  BENEFICIOS4 NUMBER(8),
  PRIMARY KEY (DPTO#));


-- TABLA PUESTOS

exec dbms_output.put_line('>>>> Borrando y Creando tabla PUESTOS...');
DROP   TABLE PUESTOS CASCADE CONSTRAINTS;
CREATE TABLE PUESTOS(
  PUESTO# NUMBER(4) NOT NULL,
  NOMBRE CHAR(20) NOT NULL,
  ESTUDIOST NUMBER(1) DEFAULT 0 NOT NULL
      CHECK (ESTUDIOST BETWEEN 0 AND 7), -- LIMITAMOS A 8(0-7), LOS TIPOS DE TRIBUTOS TIPO2
  ESTUDIOS1 NUMBER(2),
  ESTUDIOS2 NUMBER(2),
  ESTUDIOS3 NUMBER(2),
  ESTUDIOS4 NUMBER(2),
  PROFESIONT NUMBER(1) NOT NULL,
      CHECK (PROFESIONT BETWEEN 0 AND 4),
  PROFESIONP1 NUMBER(3,2),
  PROFESION1 NUMBER(3) NOT NULL,
  EXPERIENCIAT NUMBER(1) NOT NULL,
      CHECK (EXPERIENCIAT BETWEEN 0 AND 7),
  EXPERIENCIA1 NUMBER(2),
  EXPERIENCIA2 NUMBER(2),
  EXPERIENCIA3 NUMBER(2),
  EXPERIENCIA4 NUMBER(2),
  PRIMARY KEY (PUESTO#));


-- TABLA EMPLEOS

exec dbms_output.put_line('>>>> Borrando y Creando tabla EMPLEOS...');
DROP   TABLE EMPLEOS;
CREATE TABLE EMPLEOS(
  EMP# NUMBER(4) NOT NULL,
  DPTO# NUMBER(4) NOT NULL,
  PUESTO# NUMBER(4) NOT NULL,
  SUELDO NUMBER(7) NOT NULL,
  COMISIONT NUMBER(1) NOT NULL,
      CHECK (COMISIONT BETWEEN 0 AND 7),
  COMISION1 NUMBER(7),
  COMISION2 NUMBER(7),
  COMISION3 NUMBER(7),
  COMISION4 NUMBER(7),
  RENDIMIENTOT NUMBER(1) NOT NULL,
      CHECK (RENDIMIENTOT BETWEEN 0 AND 4),
  RENDIMIENTOP1 NUMBER(3,2),
  RENDIMIENTO1 NUMBER(3) NOT NULL,
  PRIMARY KEY (EMP#,DPTO#,PUESTO#),
  FOREIGN KEY (EMP#) REFERENCES EMPLEADOS ON DELETE CASCADE,
  FOREIGN KEY (EMP#) REFERENCES APTITUDES ON DELETE CASCADE,
  FOREIGN KEY (DPTO#) REFERENCES DEPARTAMENTOS ON DELETE CASCADE,
  FOREIGN KEY (PUESTO#) REFERENCES PUESTOS ON DELETE CASCADE);


DECLARE
  t_APTITUDES  	NUMBER;
  t_EMPLEOS    	NUMBER;
  t_PUESTOS    	NUMBER;
  t_DEPARTAMENTOS NUMBER;
  t_EMPLEADOS  	NUMBER;
  c_estudios 	NUMBER;
  c_experiencia NUMBER;
  c_profesion	NUMBER;
  c_comision    NUMBER;
  c_rendimiento NUMBER;
  c_sueldo      NUMBER;
  c_estudios1   NUMBER;
  c_experiencia1  NUMBER;
  c_profesion1  NUMBER;
  c_beneficios	NUMBER;
  c_edad        NUMBER;
BEGIN
  dbms_output.put_line('>>>> Insertando valores en la FMB sobre esta Bd Difusa...');

  -- Calcular OBJ# para las tablas con columnas difusas:
  SELECT object_id into t_APTITUDES FROM user_objects WHERE object_name='APTITUDES';
  SELECT object_id into t_EMPLEOS FROM user_objects WHERE object_name='EMPLEOS';
  SELECT object_id into t_PUESTOS FROM user_objects WHERE object_name='PUESTOS';
  SELECT object_id into t_DEPARTAMENTOS       FROM user_objects WHERE object_name='DEPARTAMENTOS';
  SELECT object_id into t_EMPLEADOS   FROM user_objects WHERE object_name='EMPLEADOS';

  -- Calcular COL# de las columnas difusas:
  SELECT column_id into c_estudios
    FROM user_tab_columns WHERE table_name='APTITUDES' AND column_name='ESTUDIOST';
  SELECT column_id into c_experiencia
    FROM user_tab_columns WHERE table_name='APTITUDES' AND column_name='EXPERIENCIAT';
  SELECT column_id into c_profesion
    FROM user_tab_columns WHERE table_name='APTITUDES' AND column_name='PROFESIONT';
  SELECT column_id into c_comision
    FROM user_tab_columns WHERE table_name='EMPLEOS' AND column_name='COMISIONT';
  SELECT column_id into c_rendimiento
    FROM user_tab_columns WHERE table_name='EMPLEOS' AND column_name='RENDIMIENTOT';
  SELECT column_id into c_sueldo
    FROM user_tab_columns WHERE table_name='EMPLEOS' AND column_name='SUELDO';
  SELECT column_id into c_estudios1
    FROM user_tab_columns WHERE table_name='PUESTOS' AND column_name='ESTUDIOST';
  SELECT column_id into c_experiencia1
    FROM user_tab_columns WHERE table_name='PUESTOS' AND column_name='EXPERIENCIAT';
  SELECT column_id into c_profesion1
    FROM user_tab_columns WHERE table_name='PUESTOS' AND column_name='PROFESIONT';
  SELECT column_id into c_beneficios
    FROM user_tab_columns WHERE table_name='DEPARTAMENTOS' AND column_name='BENEFICIOST';
  SELECT column_id into c_edad
    FROM user_tab_columns WHERE table_name='EMPLEADOS' AND column_name='EDADT';
 

  -- Atributos con tratamiento difuso: Tipos 1, 2  3
  INSERT into FCL values (t_APTITUDES,c_estudios,2,1,USER||'.APTITUDES.ESTUDIOS');
  INSERT into FCL values (t_APTITUDES,c_experiencia,2,1,USER||'.APTITUDES.EXPERIENCIA');
  INSERT into FCL values (t_APTITUDES,c_profesion,3,1,USER||'.APTITUDES.PROFESION');
  INSERT into FCL values (t_EMPLEOS,c_comision,2,1,USER||'.EMPLEOS.COMISION');
  INSERT into FCL values (t_EMPLEOS,c_rendimiento,3,1,USER||'.EMPLEOS.RENDIMIENTO');
  INSERT into FCL values (t_EMPLEOS,c_sueldo,1,1,USER||'.EMPLEOS.SUELDO');
  INSERT into FCL values (t_PUESTOS,c_estudios1,2,1,USER||'.PUESTOS.ESTUDIOS');
  INSERT into FCL values (t_PUESTOS,c_experiencia1,2,1,USER||'.PUESTOS.EXPERIENCIA');
  INSERT into FCL values (t_PUESTOS,c_profesion1,3,1,USER||'.PUESTOS.PROFESION');
  INSERT into FCL values (t_DEPARTAMENTOS,c_beneficios,2,1,USER||'.DEPARTAMENTOS.BENEFICIOS');
  INSERT into FCL values (t_EMPLEADOS,c_edad,2,1,USER||'.EMPLEADOS.EDAD');


  -- COMPATIBILIDAD de atributos tipo 3:
  -- Campo PUESTOS.profesion es compatible con APTITUDES.profesion
  INSERT into FCC values (t_PUESTOS,c_profesion1,t_APTITUDES,c_profesion);

  -- Objetos para la tabla EMPLEOS:
  INSERT into FOL values (t_EMPLEOS,c_sueldo,0,'MUY_BAJO',0);
  INSERT into FOL values (t_EMPLEOS,c_sueldo,1,'BAJO',0);
  INSERT into FOL values (t_EMPLEOS,c_sueldo,2,'MEDIO',0);
  INSERT into FOL values (t_EMPLEOS,c_sueldo,3,'ALTO',0);
  INSERT into FOL values (t_EMPLEOS,c_sueldo,4,'MUY_ALTO',0);
  INSERT into FOL values (t_EMPLEOS,c_sueldo,5,'ALTISIMO',0);
  INSERT into FOL values (t_EMPLEOS,c_comision,0,'REDUCIDA',0);
  INSERT into FOL values (t_EMPLEOS,c_comision,1,'BAJA',0);
  INSERT into FOL values (t_EMPLEOS,c_comision,2,'NORMAL',0);
  INSERT into FOL values (t_EMPLEOS,c_comision,3,'ALTA',0);
  INSERT into FOL values (t_EMPLEOS,c_comision,4,'ELEVADA',0);
  INSERT into FOL values (t_EMPLEOS,c_rendimiento,0,'MALO',1);
  INSERT into FOL values (t_EMPLEOS,c_rendimiento,1,'REGULAR',1);
  INSERT into FOL values (t_EMPLEOS,c_rendimiento,2,'BUENO',1);
  INSERT into FOL values (t_EMPLEOS,c_rendimiento,3,'MUY_BUENO',1);
  INSERT into FOL values (t_EMPLEOS,c_rendimiento,4,'EXCELENTE',1);

  -- Objetos para la tabla APTITUDES:
  INSERT into FOL values(t_APTITUDES,c_estudios,0,'PRIMARIA',0);
  INSERT into FOL values(t_APTITUDES,c_estudios,1,'SECUNDARIA',0);
  INSERT into FOL values(t_APTITUDES,c_estudios,2,'DIPLOMADO',0);
  INSERT into FOL values(t_APTITUDES,c_estudios,3,'LICENCIADO',0);
  INSERT into FOL values(t_APTITUDES,c_estudios,4,'DOCTOR',0);
  INSERT into FOL values(t_APTITUDES,c_profesion,0,'ECONOMISTA',1);
  INSERT into FOL values(t_APTITUDES,c_profesion,1,'INFORMATICO',1);
  INSERT into FOL values(t_APTITUDES,c_profesion,2,'TELECOMUNICACIONES',1);
  INSERT into FOL values(t_APTITUDES,c_profesion,3,'CREATIVO',1);
  INSERT into FOL values(t_APTITUDES,c_profesion,4,'ADMINISTRATIVO',1);
  INSERT into FOL values(t_APTITUDES,c_profesion,5,'COMERCIAL',1);
  INSERT into FOL values(t_APTITUDES,c_experiencia,0,'POCA',0);
  INSERT into FOL values(t_APTITUDES,c_experiencia,1,'ALGUNA',0);
  INSERT into FOL values(t_APTITUDES,c_experiencia,2,'MUCHA',0);
  INSERT into FOL values(t_APTITUDES,c_experiencia,3,'BASTANTE',0);
  INSERT into FOL values(t_APTITUDES,c_experiencia,4,'GRANDE',0);

  -- Objetos para la tabla PUESTOS:
  INSERT into FOL values(t_PUESTOS,c_estudios1,0,'PRIMARIA',0);
  INSERT into FOL values(t_PUESTOS,c_estudios1,1,'SECUNDARIA',0);
  INSERT into FOL values(t_PUESTOS,c_estudios1,2,'DIPLOMADO',0);
  INSERT into FOL values(t_PUESTOS,c_estudios1,3,'LICENCIADO',0);
  INSERT into FOL values(t_PUESTOS,c_estudios1,4,'DOCTOR',0);  
  INSERT into FOL values(t_PUESTOS,c_experiencia1,0,'POCA',0);
  INSERT into FOL values(t_PUESTOS,c_experiencia1,1,'ALGUNA',0);
  INSERT into FOL values(t_PUESTOS,c_experiencia1,2,'MUCHA',0);
  INSERT into FOL values(t_PUESTOS,c_experiencia1,3,'BASTANTE',0);
  INSERT into FOL values(t_PUESTOS,c_experiencia1,4,'GRANDE',0);

  -- Objetos para la tabla DEPARTAMENTOS:
  INSERT into FOL values(t_DEPARTAMENTOS,c_beneficios,0,'ESCASOS',0);
  INSERT into FOL values(t_DEPARTAMENTOS,c_beneficios,1,'POCOS',0);
  INSERT into FOL values(t_DEPARTAMENTOS,c_beneficios,2,'MODERADOS',0);
  INSERT into FOL values(t_DEPARTAMENTOS,c_beneficios,3,'ELEVADOS',0);

  -- Objetos para la tabla EMPLEADOS:
  INSERT into FOL values(t_EMPLEADOS,c_edad,0,'MUY_JOVEN',0);
  INSERT into FOL values(t_EMPLEADOS,c_edad,1,'JOVEN',0);
  INSERT into FOL values(t_EMPLEADOS,c_edad,2,'MADURO',0);
  INSERT into FOL values(t_EMPLEADOS,c_edad,3,'MAYOR',0);
  INSERT into FOL values(t_EMPLEADOS,c_edad,4,'MUY_MAYOR',0);

  -- Definicin de las etiquetas lingsticas:
  INSERT into FLD values(t_EMPLEADOS,c_edad,0,16,16,20,26);
  INSERT into FLD values(t_EMPLEADOS,c_edad,1,18,22,30,35);
  INSERT into FLD values(t_EMPLEADOS,c_edad,2,25,32,45,50);
  INSERT into FLD values(t_EMPLEADOS,c_edad,3,40,45,55,60);
  INSERT into FLD values(t_EMPLEADOS,c_edad,4,50,55,62,70);

  INSERT into FLD values(t_APTITUDES,c_experiencia,0,0,0,1,2);
  INSERT into FLD values(t_APTITUDES,c_experiencia,1,1,2,4,5);
  INSERT into FLD values(t_APTITUDES,c_experiencia,2,4,5,8,10);
  INSERT into FLD values(t_APTITUDES,c_experiencia,3,7,8,15,20);
  INSERT into FLD values(t_APTITUDES,c_experiencia,4,12,15,50,50);
  INSERT into FLD values(t_APTITUDES,c_estudios,0,0,0,1,1);
  INSERT into FLD values(t_APTITUDES,c_estudios,1,1,1,2,2);
  INSERT into FLD values(t_APTITUDES,c_estudios,2,2,2,3,3);
  INSERT into FLD values(t_APTITUDES,c_estudios,3,3,3,4,4);
  INSERT into FLD values(t_APTITUDES,c_estudios,4,4,4,5,5);

  INSERT into FLD values(t_PUESTOS,c_experiencia1,0,0,0,1,2); 
  INSERT into FLD values(t_PUESTOS,c_experiencia1,1,1,2,4,5);
  INSERT into FLD values(t_PUESTOS,c_experiencia1,2,4,5,8,10);
  INSERT into FLD values(t_PUESTOS,c_experiencia1,3,7,8,15,20);
  INSERT into FLD values(t_PUESTOS,c_experiencia1,4,12,15,50,50);
  INSERT into FLD values(t_PUESTOS,c_estudios1,0,0,0,1,1);
  INSERT into FLD values(t_PUESTOS,c_estudios1,1,1,1,2,2);
  INSERT into FLD values(t_PUESTOS,c_estudios1,2,2,2,3,3);
  INSERT into FLD values(t_PUESTOS,c_estudios1,3,3,3,4,4);
  INSERT into FLD values(t_PUESTOS,c_estudios1,4,4,4,5,5);

  INSERT into FLD values(t_DEPARTAMENTOS,c_beneficios,0,0,1000000,2000000,3000000);
  INSERT into FLD values(t_DEPARTAMENTOS,c_beneficios,1,1500000,3000000,5000000,7000000);
  INSERT into FLD values(t_DEPARTAMENTOS,c_beneficios,2,3000000,4500000,10000000,14000000);
  INSERT into FLD values(t_DEPARTAMENTOS,c_beneficios,3,7000000,10000000,100000000,100000000);

  INSERT into FLD values(t_EMPLEOS,c_sueldo,0,50000,55000,80000,100000);
  INSERT into FLD values(t_EMPLEOS,c_sueldo,1,75000,90000,140000,155000);
  INSERT into FLD values(t_EMPLEOS,c_sueldo,2,125000,155000,195000,205000);
  INSERT into FLD values(t_EMPLEOS,c_sueldo,3,195000,215000,285000,310000);
  INSERT into FLD values(t_EMPLEOS,c_sueldo,4,300000,320000,400000,420000);
  INSERT into FLD values(t_EMPLEOS,c_sueldo,5,410000,430000,1000000,1000000);

  INSERT into FLD values(t_EMPLEOS,c_comision,0,0,5000,10000,15000);
  INSERT into FLD values(t_EMPLEOS,c_comision,1,11000,15000,20000,30000);
  INSERT into FLD values(t_EMPLEOS,c_comision,2,15000,17000,30000,40000);
  INSERT into FLD values(t_EMPLEOS,c_comision,3,20000,32000,50000,60000);
  INSERT into FLD values(t_EMPLEOS,c_comision,4,40000,50000,200000,300000);


  -- Definicin de las relaciones de semejanza:
  INSERT into FND values(t_APTITUDES,c_profesion,0,1,.6);
  INSERT into FND values(t_APTITUDES,c_profesion,0,2,.6);
  INSERT into FND values(t_APTITUDES,c_profesion,0,3,.3);
  INSERT into FND values(t_APTITUDES,c_profesion,0,4,.8);
  INSERT into FND values(t_APTITUDES,c_profesion,0,5,.7);
  INSERT into FND values(t_APTITUDES,c_profesion,1,2,.8);
  INSERT into FND values(t_APTITUDES,c_profesion,1,3,.6);
  INSERT into FND values(t_APTITUDES,c_profesion,1,4,.3);
  INSERT into FND values(t_APTITUDES,c_profesion,1,5,.4);
  INSERT into FND values(t_APTITUDES,c_profesion,2,3,.4);
  INSERT into FND values(t_APTITUDES,c_profesion,2,4,.3);
  INSERT into FND values(t_APTITUDES,c_profesion,2,5,.5);
  INSERT into FND values(t_APTITUDES,c_profesion,3,4,.2);
  INSERT into FND values(t_APTITUDES,c_profesion,3,5,.4);
  INSERT into FND values(t_APTITUDES,c_profesion,4,5,.7);

  INSERT into FND values(t_EMPLEOS,c_rendimiento,0,1,.8);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,0,2,.4);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,0,3,.2);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,0,4,.1);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,1,2,.7);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,1,3,.3);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,1,4,.2);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,2,3,.8);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,2,4,.5);
  INSERT into FND values(t_EMPLEOS,c_rendimiento,3,4,.7);

  -- Definicin de: 
  -- 1) Mrgenes para valores APROX en cada columna y
  -- 2) Distancia Mnima para afirmar en los comparadores MGT y MLT.
  INSERT into FAM values(t_EMPLEADOS,c_edad,5,10);
  -- En EDAD:
  -- 1) Si decimos "Aproximadamente 15 aos", entendemos 155
  -- 2) Para que dos edades sean MUY diferentes (MGT  MLT), tendrn que diferir en 5 aos
  INSERT into FAM values(t_APTITUDES,c_estudios,.0,1);
  INSERT into FAM values(t_APTITUDES,c_experiencia,2,5);
  INSERT into FAM values(t_DEPARTAMENTOS,c_beneficios,2000000,4000000);
  INSERT into FAM values(t_PUESTOS,c_estudios1,.0,1);
  INSERT into FAM values(t_PUESTOS,c_experiencia1,2,5);
  INSERT into FAM values(t_EMPLEOS,c_sueldo,10000,50000);
  INSERT into FAM values(t_EMPLEOS,c_comision,5000,15000);


  -- INSERTAMOS REGISTROS EN LAS TABLAS DEFINIDAS

  dbms_output.put_line('>>>> Insertando valores en las tablas de esta Bd Difusa...');
  -- *****  INSERCIONES de los valores de las tablas ***** --
  INSERT into EMPLEADOS values (0 ,'VICTOR'   ,'GOMEZ ROBLES','V',4,0,NULL,NULL,NULL,'837483732');
  INSERT into EMPLEADOS values (1 ,'JAVIER'   ,'PEREZ GARCIA','V',3,17,NULL,NULL,NULL,'934758356');
  INSERT into EMPLEADOS values (2 ,'OLGA'     ,'DE LA TORRE MORENO','H',3,27,NULL,NULL,NULL,'836746372');
  INSERT into EMPLEADOS values (3 ,'JOSE'     ,'LASA NARANJO','V',5,25,0,0,30,'952834758');
  INSERT into EMPLEADOS values (4 ,'SALVADOR' ,'DE MIGUEL MARTOS','V',7,40,5,-7,55,'937463037');
  INSERT into EMPLEADOS values (5 ,'SANDRA'   ,'ROMAN ROJAS','H',6,30,25,35,5,'937461048');
  INSERT into EMPLEADOS values (6 ,'ANA'      ,'LOPEZ DOBLAS','H',0,23,NULL,NULL,NULL,'952837473');
  INSERT into EMPLEADOS values (7 ,'IGNACIO'  ,'ROBLEDO LAIZ','V',3,45,NULL,NULL,NULL,'988762100');
  INSERT into EMPLEADOS values (8 ,'LUIS'     ,'DE TOMAS RUIZ','V',3,18,NULL,NULL,NULL,'983746211');
  INSERT into EMPLEADOS values (9 ,'ALBERTO'  ,'GUTIERREZ DENIA','V',3,23,NULL,NULL,NULL,'95263482');
  INSERT into EMPLEADOS values (10,'ALVARO'   ,'CID LAFUENTE','V',4,1,NULL,NULL,NULL,'952847384');
  INSERT into EMPLEADOS values (11,'LAURA'    ,'CABELLO RUBIO','H',4,3,NULL,NULL,NULL,'98473622');
  INSERT into EMPLEADOS values (12,'CARLOS'   ,'TURIEL ARGANDA','V',4,4,NULL,NULL,NULL,'916273633');
  INSERT into EMPLEADOS values (13,'CRISTINA' ,'ANTEQUERA GARCIA','H',4,2,NULL,NULL,NULL,'952003422');
  INSERT into EMPLEADOS values (14,'INES'     ,'SANZ RATO','H',4,1,NULL,NULL,NULL,'926374826');
  INSERT into EMPLEADOS values (15,'JULIAN'   ,'BLANCO SANCHEZ','V',3,31,NULL,NULL,NULL,'928374423');
  INSERT into EMPLEADOS values (16,'ANTONIO'  ,'MARTIN GONZALEZ','V',3,55,NULL,NULL,NULL,'988273100');
  INSERT into EMPLEADOS values (17,'SILVIA'   ,'VALENCIA MARMOLEJO','H',6,35,30,40,5,'983273441');
  INSERT into EMPLEADOS values (18,'PALOMA'   ,'SAN MARTIN PICARD','H',7,28,4,-3,42,'916273300');
  INSERT into EMPLEADOS values (19,'DAVID'    ,'MOLINA FERNANDEZ','V',4,1,NULL,NULL,NULL,'934333232');
  INSERT into EMPLEADOS values (20,'CARMEN'   ,'VALDIVIESO FUENTES','H',3,60,NULL,NULL,NULL,'923844091');
  INSERT into EMPLEADOS values (21,'JUAN'     ,'ZAMORA JIMENEZ','V',3,48,NULL,NULL,NULL,'928732278');
  INSERT into EMPLEADOS values (22,'RAFA'     ,'VAZQUEZ SORIA','V',3,29,NULL,NULL,NULL,'952272288');
  INSERT into EMPLEADOS values (23,'JOSE LUIS','RICO HERAS','V',3,34,NULL,NULL,NULL,'98433011');
  INSERT into EMPLEADOS values (24,'PATRICIA' ,'RODRIGUEZ SILVA','H',3,27,NULL,NULL,NULL,'951772122');
  INSERT into EMPLEADOS values (25,'DOLORES'  ,'NARVAEZ SEGOVIA','H',3,34,NULL,NULL,NULL,'951233037');

  INSERT into APTITUDES values (0 ,4,0,NULL,NULL,NULL,3,1,5,4,0,NULL,NULL,NULL);
  INSERT into APTITUDES values (1 ,4,0,NULL,NULL,NULL,3,1,3,4,0,NULL,NULL,NULL);
  INSERT into APTITUDES values (2 ,4,2,NULL,NULL,NULL,3,1,1,4,1,NULL,NULL,NULL);
  INSERT into APTITUDES values (3 ,4,1,NULL,NULL,NULL,3,1,3,3,3,NULL,NULL,NULL);
  INSERT into APTITUDES values (4 ,4,1,NULL,NULL,NULL,3,1,5,3,20,NULL,NULL,NULL);
  INSERT into APTITUDES values (5 ,4,4,NULL,NULL,NULL,3,1,0,5,15,NULL,NULL,20);
  INSERT into APTITUDES values (6 ,4,0,NULL,NULL,NULL,3,1,4,0,23,NULL,NULL,NULL);
  INSERT into APTITUDES values (7 ,4,3,NULL,NULL,NULL,3,1,2,4,3,NULL,NULL,NULL);
  INSERT into APTITUDES values (8 ,4,1,NULL,NULL,NULL,3,1,5,3,1,NULL,NULL,NULL);
  INSERT into APTITUDES values (9 ,4,1,NULL,NULL,NULL,3,1,3,6,2,0,4,2);
  INSERT into APTITUDES values (10,4,1,NULL,NULL,NULL,3,1,4,4,1,NULL,NULL,NULL);
  INSERT into APTITUDES values (11,4,0,NULL,NULL,NULL,3,1,0,4,3,NULL,NULL,NULL);
  INSERT into APTITUDES values (12,4,2,NULL,NULL,NULL,3,1,1,3,20,NULL,NULL,NULL);
  INSERT into APTITUDES values (13,4,3,NULL,NULL,NULL,3,1,3,3,15,NULL,NULL,NULL);
  INSERT into APTITUDES values (14,4,1,NULL,NULL,NULL,3,1,4,6,3,1,5,2);
  INSERT into APTITUDES values (15,4,2,NULL,NULL,NULL,3,1,1,7,2,4,-4,17);
  INSERT into APTITUDES values (16,4,1,NULL,NULL,NULL,3,1,3,4,3,NULL,NULL,NULL);
  INSERT into APTITUDES values (17,4,2,NULL,NULL,NULL,3,1,1,3,7,NULL,NULL,NULL);
  INSERT into APTITUDES values (18,4,2,NULL,NULL,NULL,3,1,2,3,4,NULL,NULL,NULL);
  INSERT into APTITUDES values (19,4,1,NULL,NULL,NULL,3,1,5,4,1,NULL,NULL,NULL);
  INSERT into APTITUDES values (20,4,2,NULL,NULL,NULL,3,1,2,4,4,NULL,NULL,NULL);
  INSERT into APTITUDES values (21,4,1,NULL,NULL,NULL,3,1,2,4,3,NULL,NULL,NULL);
  INSERT into APTITUDES values (22,4,3,NULL,NULL,NULL,3,1,1,4,1,NULL,NULL,NULL);
  INSERT into APTITUDES values (23,4,4,NULL,NULL,NULL,3,1,1,4,2,NULL,NULL,NULL);
  INSERT into APTITUDES values (24,4,0,NULL,NULL,NULL,3,1,5,6,15,13,17,2);
  INSERT into APTITUDES values (25,4,0,NULL,NULL,NULL,3,1,4,4,0,NULL,NULL,NULL);

  INSERT into DEPARTAMENTOS values (0,'DIRECCION',6,3000000,1000000,5000000,2000000);
  INSERT into DEPARTAMENTOS values (1,'PROGRAMACION',4,2,NULL,NULL,NULL);
  INSERT into DEPARTAMENTOS values (2,'DISEO',5,5000000,NULL,NULL,8000000);
  INSERT into DEPARTAMENTOS values (3,'SISTEMAS',7,2000000,500000,-500000,6000000);
  INSERT into DEPARTAMENTOS values (4,'ADMINISTRACION',3,1500000,NULL,NULL,NULL);
  INSERT into DEPARTAMENTOS values (5,'COMERCIAL',4,0,NULL,NULL,NULL);

  INSERT into PUESTOS values (0 ,'DIRECTOR'		,4,3,NULL,NULL,NULL,3,1,0,4,4,NULL,NULL,NULL);
  INSERT into PUESTOS values (1 ,'JEFE DPTO' 		,4,3,NULL,NULL,NULL,3,1,1,4,2,NULL,NULL,NULL);
  INSERT into PUESTOS values (2 ,'ANALISTA'		,4,2,NULL,NULL,NULL,3,1,1,4,2,NULL,NULL,NULL);
  INSERT into PUESTOS values (3 ,'PROGRAMADOR'	,4,2,NULL,NULL,NULL,3,1,1,4,1,NULL,NULL,NULL);
  INSERT into PUESTOS values (4 ,'TECNICO'  		,4,1,NULL,NULL,NULL,3,1,2,4,0,NULL,NULL,NULL);
  INSERT into PUESTOS values (5 ,'DISEADOR' 		,4,1,NULL,NULL,NULL,3,1,2,4,1,NULL,NULL,NULL);
  INSERT into PUESTOS values (6 ,'ADMINISTRATIVO'	,4,1,NULL,NULL,NULL,3,1,3,4,1,NULL,NULL,NULL);
  INSERT into PUESTOS values (7 ,'ADMINISTRATIVO AUX'	,4,1,NULL,NULL,NULL,3,1,3,4,0,NULL,NULL,NULL);
  INSERT into PUESTOS values (8 ,'SECRETARIO'		,4,0,NULL,NULL,NULL,3,1,4,4,1,NULL,NULL,NULL);
  INSERT into PUESTOS values (9 ,'COMERCIAL' 		,4,0,NULL,NULL,NULL,3,1,5,4,2,NULL,NULL,NULL);
  INSERT into PUESTOS values (10,'COMERCIAL AUX1'	,4,0,NULL,NULL,NULL,3,1,5,3,0,NULL,NULL,NULL);
  INSERT into PUESTOS values (11,'COMERCIAL AUX2'	,4,0,NULL,NULL,NULL,3,1,5,0,NULL,NULL,NULL,NULL);
  INSERT into PUESTOS values (12,'COMERCIAL AUX3'	,4,0,NULL,NULL,NULL,3,1,5,1,NULL,NULL,NULL,NULL);

  INSERT into EMPLEOS values (0 ,5,11, 60000,3,10000,NULL,NULL,NULL,3,1,1);
  INSERT into EMPLEOS values (1 ,5,10, 80000,3,5000,NULL,NULL,NULL,3,1,3);
  INSERT into EMPLEOS values (2 ,1,1 ,230000,4,2,NULL,NULL,NULL,3,1,1);
  INSERT into EMPLEOS values (3 ,1,3 ,120000,3,10000,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (4 ,5,1 ,160000,4,3,NULL,NULL,NULL,3,1,3);
  INSERT into EMPLEOS values (5 ,0,0 ,420000,3,30000,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (6 ,2,4 ,120000,4,0,NULL,NULL,NULL,3,1,1);
  INSERT into EMPLEOS values (7 ,0,0 ,500000,4,4,NULL,NULL,NULL,3,1,3);
  INSERT into EMPLEOS values (8 ,2,5 , 90000,3,35000,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (9 ,1,3 ,120000,6,5000,0,10000,5000,3,1,2);
  INSERT into EMPLEOS values (10,3,4 ,130000,4,1,NULL,NULL,NULL,3,1,0);
  INSERT into EMPLEOS values (11,1,2 ,450000,4,4,NULL,NULL,NULL,3,1,4);
  INSERT into EMPLEOS values (12,3,1 ,215000,3,40000,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (13,4,1 ,375000,3,50000,NULL,NULL,NULL,3,1,0);
  INSERT into EMPLEOS values (14,3,4 ,150000,4,1,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (15,2,1 ,230000,7,50000,10000,-15000,100000,3,1,2);
  INSERT into EMPLEOS values (16,1,3 ,170000,4,2,NULL,NULL,NULL,3,1,3);
  INSERT into EMPLEOS values (17,4,6 ,135000,4,0,NULL,NULL,NULL,3,1,0);
  INSERT into EMPLEOS values (18,2,5 ,160000,3,20000,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (19,4,7 ,120000,4,0,NULL,NULL,NULL,3,1,3);
  INSERT into EMPLEOS values (20,0,2 ,255000,4,3,NULL,NULL,NULL,3,1,2);
  INSERT into EMPLEOS values (21,3,2 ,205000,6,25000,20000,30000,5000,3,1,2);
  INSERT into EMPLEOS values (22,1,2 ,200000,4,1,NULL,NULL,NULL,3,1,4);
  INSERT into EMPLEOS values (23,5,9 , 85000,4,2,NULL,NULL,NULL,3,1,1);
  INSERT into EMPLEOS values (24,5,12, 85000,4,1,NULL,NULL,NULL,3,1,0);
  INSERT into EMPLEOS values (25,0,8 , 70000,3,0,NULL,NULL,NULL,3,1,1);	
  COMMIT;
END;
/

-- Mensaje de FIN:
exec dbms_output.put_line('>>>>');
exec dbms_output.put_line('>>>> FIN de la INSTALACIN: Si existieron errores, revise su texto.');
exec dbms_output.put_line('>>>>');

-- Reestablecer los valores por defecto:
set serveroutput off
set feedback on
